==> unit-1.0.41-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractSourceTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractSourceTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public Header header;
	public SourceTemplate.Header. _7_8_12014258538 _7_8_12014258538;
	public SourceTemplate.Header._7_8_12014258538. _8_12_1952734992 _8_12_1952734992;
	public SourceTemplate.Header._7_8_12014258538._8_12_1952734992. DesktopLink desktopLink;
	public SourceTemplate.Header._7_8_12014258538._8_12_1952734992. DesktopLinkSeparator desktopLinkSeparator;
	public SourceTemplate.Header._7_8_12014258538._8_12_1952734992. Label label;
	public SourceTemplate.Header._7_8_12014258538. Count count;
	public SourceLegendTemplate _13_12_01116687971;
	public _15_4_11690252698 _15_4_11690252698;
	public SourceTemplate._15_4_11690252698. _16_8_1286889868 _16_8_1286889868;
	public SourceEmbeddedTemplate content;

    public AbstractSourceTemplate(B box) {
        super(box);
        id("sourceTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (header == null) header = register(new Header(box()).<Header>id("a593751384").owner(AbstractSourceTemplate.this));
		if (header != null) _7_8_12014258538 = header._7_8_12014258538;
		if (_7_8_12014258538 != null) _8_12_1952734992 = header._7_8_12014258538._8_12_1952734992;
		if (_8_12_1952734992 != null) desktopLink = header._7_8_12014258538._8_12_1952734992.desktopLink;
		if (_8_12_1952734992 != null) desktopLinkSeparator = header._7_8_12014258538._8_12_1952734992.desktopLinkSeparator;
		if (_8_12_1952734992 != null) label = header._7_8_12014258538._8_12_1952734992.label;
		if (_7_8_12014258538 != null) count = header._7_8_12014258538.count;
		if (_7_8_12014258538 != null) _13_12_01116687971 = header._7_8_12014258538._13_12_01116687971;
		if (_15_4_11690252698 == null) _15_4_11690252698 = register(new _15_4_11690252698(box()).<_15_4_11690252698>id("a1021661025").owner(AbstractSourceTemplate.this));
		if (_15_4_11690252698 != null) _16_8_1286889868 = _15_4_11690252698._16_8_1286889868;
		if (_16_8_1286889868 != null) content = _15_4_11690252698._16_8_1286889868.content;
	}

	public class Header extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public SourceTemplate.Header. _7_8_12014258538 _7_8_12014258538;

		public Header(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_7_8_12014258538 == null) _7_8_12014258538 = register(new _7_8_12014258538(box()).<_7_8_12014258538>id("a382977072").owner(AbstractSourceTemplate.this));
		}

		public class _7_8_12014258538 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public SourceTemplate.Header._7_8_12014258538. _8_12_1952734992 _8_12_1952734992;
			public SourceTemplate.Header._7_8_12014258538. Count count;
			public SourceLegendTemplate _13_12_01116687971;

			public _7_8_12014258538(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_8_12_1952734992 == null) _8_12_1952734992 = register(new _8_12_1952734992(box()).<_8_12_1952734992>id("a245674698").owner(AbstractSourceTemplate.this));
				if (count == null) count = register(new Count(box()).<Count>id("a_1984517316").owner(AbstractSourceTemplate.this));
				if (_13_12_01116687971 == null) _13_12_01116687971 = register(new SourceLegendTemplate((UnitBox)box()).id("a1213255366"));
			}

			public class _8_12_1952734992 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public SourceTemplate.Header._7_8_12014258538._8_12_1952734992. DesktopLink desktopLink;
				public SourceTemplate.Header._7_8_12014258538._8_12_1952734992. DesktopLinkSeparator desktopLinkSeparator;
				public SourceTemplate.Header._7_8_12014258538._8_12_1952734992. Label label;

				public _8_12_1952734992(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (desktopLink == null) desktopLink = register(new DesktopLink(box()).<DesktopLink>id("a_133684349").owner(AbstractSourceTemplate.this));
					if (desktopLinkSeparator == null) desktopLinkSeparator = register(new DesktopLinkSeparator(box()).<DesktopLinkSeparator>id("a2076123810").owner(AbstractSourceTemplate.this));
					if (label == null) label = register(new Label(box()).<Label>id("a1992333825").owner(AbstractSourceTemplate.this));
				}

				public class DesktopLink extends io.intino.alexandria.ui.displays.components.Action<io.intino.alexandria.ui.displays.notifiers.ActionNotifier, B> implements io.intino.alexandria.ui.displays.components.addressable.Addressed<DesktopLink> {

					public DesktopLink(B box) {
						super(box);
						_title("");
						_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Link"));
						_path("");
					}

					@Override
					public void init() {
						super.init();
					}
					@Override
					public DesktopLink address(java.util.function.Function<String, String> addressFromPathResolver) {
					    address(addressFromPathResolver.apply(path()));
					    return this;
					}
				}

				public class DesktopLinkSeparator extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

					public DesktopLinkSeparator(B box) {
						super(box);
						_value("/");
					}

					@Override
					public void init() {
						super.init();
					}
				}

				public class Label extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

					public Label(B box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
					}
				}
			}

			public class Count extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public Count(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}
			}
		}
	}

	public class _15_4_11690252698 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public SourceTemplate._15_4_11690252698. _16_8_1286889868 _16_8_1286889868;

		public _15_4_11690252698(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_16_8_1286889868 == null) _16_8_1286889868 = register(new _16_8_1286889868(box()).<_16_8_1286889868>id("a_780407708").owner(AbstractSourceTemplate.this));
		}

		public class _16_8_1286889868 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public SourceEmbeddedTemplate content;

			public _16_8_1286889868(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (content == null) content = register(new SourceEmbeddedTemplate((UnitBox)box()).id("a1439598428"));
			}
		}
	}
}

==> unit-1.1.7-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractSourceTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractSourceTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public Header header;
	public SourceTemplate.Header. _7_8_12014258538 _7_8_12014258538;
	public SourceTemplate.Header._7_8_12014258538. _8_12_1952734992 _8_12_1952734992;
	public SourceTemplate.Header._7_8_12014258538._8_12_1952734992. DesktopLink desktopLink;
	public SourceTemplate.Header._7_8_12014258538._8_12_1952734992. DesktopLinkSeparator desktopLinkSeparator;
	public SourceTemplate.Header._7_8_12014258538._8_12_1952734992. Label label;
	public SourceTemplate.Header._7_8_12014258538. Count count;
	public SourceLegendTemplate _13_12_01116687971;
	public _15_4_11690252698 _15_4_11690252698;
	public SourceTemplate._15_4_11690252698. _16_8_1286889868 _16_8_1286889868;
	public SourceEmbeddedTemplate content;

    public AbstractSourceTemplate(B box) {
        super(box);
        id("sourceTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (header == null) header = register(new Header(box()).<Header>id("a593751384").owner(AbstractSourceTemplate.this));
		if (header != null) _7_8_12014258538 = header._7_8_12014258538;
		if (_7_8_12014258538 != null) _8_12_1952734992 = header._7_8_12014258538._8_12_1952734992;
		if (_8_12_1952734992 != null) desktopLink = header._7_8_12014258538._8_12_1952734992.desktopLink;
		if (_8_12_1952734992 != null) desktopLinkSeparator = header._7_8_12014258538._8_12_1952734992.desktopLinkSeparator;
		if (_8_12_1952734992 != null) label = header._7_8_12014258538._8_12_1952734992.label;
		if (_7_8_12014258538 != null) count = header._7_8_12014258538.count;
		if (_7_8_12014258538 != null) _13_12_01116687971 = header._7_8_12014258538._13_12_01116687971;
		if (_15_4_11690252698 == null) _15_4_11690252698 = register(new _15_4_11690252698(box()).<_15_4_11690252698>id("a1021661025").owner(AbstractSourceTemplate.this));
		if (_15_4_11690252698 != null) _16_8_1286889868 = _15_4_11690252698._16_8_1286889868;
		if (_16_8_1286889868 != null) content = _15_4_11690252698._16_8_1286889868.content;
	}

    @Override
    public void remove() {
        super.remove();
	    if (header != null) header.unregister();
	    if (_15_4_11690252698 != null) _15_4_11690252698.unregister();
	}

	public class Header extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public SourceTemplate.Header. _7_8_12014258538 _7_8_12014258538;

		public Header(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_7_8_12014258538 == null) _7_8_12014258538 = register(new _7_8_12014258538(box()).<_7_8_12014258538>id("a382977072").owner(AbstractSourceTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (_7_8_12014258538 != null) _7_8_12014258538.unregister();
		}

		public class _7_8_12014258538 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public SourceTemplate.Header._7_8_12014258538. _8_12_1952734992 _8_12_1952734992;
			public SourceTemplate.Header._7_8_12014258538. Count count;
			public SourceLegendTemplate _13_12_01116687971;

			public _7_8_12014258538(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_8_12_1952734992 == null) _8_12_1952734992 = register(new _8_12_1952734992(box()).<_8_12_1952734992>id("a245674698").owner(AbstractSourceTemplate.this));
				if (count == null) count = register(new Count(box()).<Count>id("a_1984517316").owner(AbstractSourceTemplate.this));
				if (_13_12_01116687971 == null) _13_12_01116687971 = register(new SourceLegendTemplate((UnitBox)box()).id("a1213255366"));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (_8_12_1952734992 != null) _8_12_1952734992.unregister();
				if (count != null) count.unregister();
				if (_13_12_01116687971 != null) _13_12_01116687971.unregister();
			}

			public class _8_12_1952734992 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public SourceTemplate.Header._7_8_12014258538._8_12_1952734992. DesktopLink desktopLink;
				public SourceTemplate.Header._7_8_12014258538._8_12_1952734992. DesktopLinkSeparator desktopLinkSeparator;
				public SourceTemplate.Header._7_8_12014258538._8_12_1952734992. Label label;

				public _8_12_1952734992(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (desktopLink == null) desktopLink = register(new DesktopLink(box()).<DesktopLink>id("a_133684349").owner(AbstractSourceTemplate.this));
					if (desktopLinkSeparator == null) desktopLinkSeparator = register(new DesktopLinkSeparator(box()).<DesktopLinkSeparator>id("a2076123810").owner(AbstractSourceTemplate.this));
					if (label == null) label = register(new Label(box()).<Label>id("a1992333825").owner(AbstractSourceTemplate.this));
				}

				@Override
				public void unregister() {
				    super.unregister();
					if (desktopLink != null) desktopLink.unregister();
					if (desktopLinkSeparator != null) desktopLinkSeparator.unregister();
					if (label != null) label.unregister();
				}

				public class DesktopLink extends io.intino.alexandria.ui.displays.components.Action<io.intino.alexandria.ui.displays.notifiers.ActionNotifier, B> implements io.intino.alexandria.ui.displays.components.addressable.Addressed<DesktopLink> {

					public DesktopLink(B box) {
						super(box);
						_title("");
						_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Link"));
						_path("");
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
					@Override
					public DesktopLink address(java.util.function.Function<String, String> addressFromPathResolver) {
					    address(addressFromPathResolver.apply(path()));
					    return this;
					}
				}

				public class DesktopLinkSeparator extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

					public DesktopLinkSeparator(B box) {
						super(box);
						_value("/");
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
				}

				public class Label extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

					public Label(B box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
				}
			}

			public class Count extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public Count(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}
		}
	}

	public class _15_4_11690252698 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public SourceTemplate._15_4_11690252698. _16_8_1286889868 _16_8_1286889868;

		public _15_4_11690252698(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_16_8_1286889868 == null) _16_8_1286889868 = register(new _16_8_1286889868(box()).<_16_8_1286889868>id("a_780407708").owner(AbstractSourceTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (_16_8_1286889868 != null) _16_8_1286889868.unregister();
		}

		public class _16_8_1286889868 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public SourceEmbeddedTemplate content;

			public _16_8_1286889868(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (content == null) content = register(new SourceEmbeddedTemplate((UnitBox)box()).id("a1439598428"));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (content != null) content.unregister();
			}
		}
	}
}
